local fork (temporary)

Dependents:   VodafoneUSBModem_bleedingedge2

Fork of USBHostWANDongle_bleedingedge by Donatien Garnier

Revision:
9:c9e9817c398c
Parent:
6:075e36a3463e
Child:
10:08bce4cd973a
--- a/USBHost/USBDeviceConnected.h	Mon Jul 30 13:51:34 2012 +0000
+++ b/USBHost/USBDeviceConnected.h	Tue Jul 31 10:37:16 2012 +0000
@@ -20,7 +20,7 @@
 #define USBDEVICECONNECTED_H
 
 #include "stdint.h"
-#include "Endpoint.h"
+#include "USBEndpoint.h"
 
 #define MAX_ENDPOINT_PER_INTERFACE  2
 #define MAX_INTF                    2
@@ -31,7 +31,7 @@
     uint8_t intf_class;
     uint8_t intf_subclass;
     uint8_t intf_protocol;
-    Endpoint * ep[MAX_ENDPOINT_PER_INTERFACE];
+    USBEndpoint * ep[MAX_ENDPOINT_PER_INTERFACE];
     FunctionPointer detach;
 }INTERFACE;
 
@@ -45,31 +45,31 @@
     USBDeviceConnected();
 
     /*
     * Attach an endpoint to this device
     *
     * @param ep pointeur on the endpoint which will be attached
     * @returns true if successful, false otherwise
     */
-    bool addEndpoint(uint8_t intf_nb, Endpoint * ep);
+    bool addEndpoint(uint8_t intf_nb, USBEndpoint * ep);
 
     /*
     * Retrieve an endpoint by its TYPE and DIRECTION
     *
     * @param intf_nb the interface on which to lookup the endpoint
     * @param type type of the endpoint looked for
     * @param direction of the endpoint looked for
     * @param index the index of the endpoint whitin the interface
     * @returns pointer on the endpoint if found, NULL otherwise
     */
-    Endpoint * getEndpoint(uint8_t intf_nb, ENDPOINT_TYPE type, ENDPOINT_DIRECTION dir, uint8_t index = 0);
+    USBEndpoint * getEndpoint(uint8_t intf_nb, ENDPOINT_TYPE type, ENDPOINT_DIRECTION dir, uint8_t index = 0);
     
     /*
     * Retrieve an endpoint by its index
     *
     * @param index index of the endpoint
     * @returns pointer on the endpoint if found, NULL otherwise
     */
-    Endpoint * getEndpoint(uint8_t intf_nb, uint8_t index);
+    USBEndpoint * getEndpoint(uint8_t intf_nb, uint8_t index);
     
     bool addInterface(uint8_t intf_nb, uint8_t intf_class, uint8_t intf_subclass, uint8_t intf_protocol);
     
@@ -181,7 +181,7 @@
 
 private:
     INTERFACE intf[MAX_INTF];
-    //Endpoint * ep[MAX_ENDPOINT_PER_DEVICE];
+    //USBEndpoint * ep[MAX_ENDPOINT_PER_DEVICE];
     uint32_t sizeControlEndpoint;
     uint8_t hub;
     uint8_t port;
@@ -45,31 +45,31 @@
 
     /*
-    * Attach an endpoint to this device
+    * Attach an USBEndpoint to this device
     *
@@ -45,31 +45,31 @@
     *
-    * @param ep pointeur on the endpoint which will be attached
+    * @param ep pointeur on the USBEndpoint which will be attached
     * @returns true if successful, false otherwise
     */
@@ -45,31 +45,31 @@
 
     /*
-    * Retrieve an endpoint by its TYPE and DIRECTION
+    * Retrieve an USBEndpoint by its TYPE and DIRECTION
     *
@@ -45,31 +45,31 @@
     *
-    * @param intf_nb the interface on which to lookup the endpoint
-    * @param type type of the endpoint looked for
-    * @param direction of the endpoint looked for
-    * @param index the index of the endpoint whitin the interface
-    * @returns pointer on the endpoint if found, NULL otherwise
+    * @param intf_nb the interface on which to lookup the USBEndpoint
+    * @param type type of the USBEndpoint looked for
+    * @param direction of the USBEndpoint looked for
+    * @param index the index of the USBEndpoint whitin the interface
+    * @returns pointer on the USBEndpoint if found, NULL otherwise
     */
@@ -45,31 +45,31 @@
     
     /*
-    * Retrieve an endpoint by its index
+    * Retrieve an USBEndpoint by its index
     *
@@ -45,31 +45,31 @@
     *
-    * @param index index of the endpoint
-    * @returns pointer on the endpoint if found, NULL otherwise
+    * @param index index of the USBEndpoint
+    * @returns pointer on the USBEndpoint if found, NULL otherwise
     */